#
# spec file for package ois
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1_5_0
Name:           ois
Version:        1.5.1
Release:        1.13
Summary:        Object Oriented Input System
License:        Zlib
Group:          System/Libraries
URL:            https://wgois.github.io/OIS/
Source0:        https://github.com/wgois/OIS/archive/refs/tags/v%{version}.tar.gz#/OIS-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)

%description
Object Oriented Input System (OIS) is a solution for using all kinds
of Input Devices (Keyboards, Mice, Joysticks, etc) and feedback
devices (e.g. forcefeedback).

%package -n libOIS%{sover}
Summary:        Object Oriented Input System development package
Group:          System/Libraries

%description -n libOIS%{sover}
Object Oriented Input System (OIS) is a solution for using all kinds
of Input Devices (Keyboards, Mice, Joysticks, etc) and feedback
devices (e.g. forcefeedback).

%package -n libOIS-devel
Summary:        Object Oriented Input System development package
Group:          Development/Libraries/C and C++
Requires:       libOIS%{sover} = %{version}

%description -n libOIS-devel
Object Oriented Input System (OIS) is a solution for using all kinds
of Input Devices (Keyboards, Mice, Joysticks, etc) and feedback
devices (e.g. forcefeedback).

%prep
%autosetup -p1 -n OIS-%{version}

%build
%cmake \
%if 0%{?sle_version} == 150200
  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
%endif
  -DOIS_BUILD_SHARED_LIBS=ON
%cmake_build

%install
%cmake_install

%post   -n libOIS%{sover} -p /sbin/ldconfig
%postun -n libOIS%{sover} -p /sbin/ldconfig

%files -n libOIS%{sover}
%license LICENSE.md
%{_libdir}/libOIS.so.*

%files -n libOIS-devel
%{_includedir}/ois
%{_libdir}/libOIS.so
%{_libdir}/pkgconfig/OIS.pc

%changelog
* Sat Jun 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.1
  * Xinput bugfix: somehow we were only using up to 3 controllers,
    not 4
  * X11 fix for getAsString()
- Drop upstream fixed
  * 0001-CMakeLists.txt-Respect-user-s-libdir.patch
  * 0001-Install-headers-from-CMAKE_CURRENT_SOURCE_DIR-instea.patch
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5
  * Clean CMake based build system
  * CapsLock and NumLock are modifiers bits
  * Improved Linux keyboard support (should not depend on the X11
    current keyboard layout anymore)
  * Added clang-format for consistent coding style
  * Diverse code cleaning and housekeeping changes
- Using cmake instead of autoconf
- Fixed sub package names to match so version
- Drop upstream fixed ois-gcc47.patch
- Add upstream patches
  * 0001-Install-headers-from-CMAKE_CURRENT_SOURCE_DIR-instea.patch
  * 0001-CMakeLists.txt-Respect-user-s-libdir.patch
* Wed Dec 13 2017 crrodriguez@opensuse.org
- Replace xorg-x11-devel for the needed individual libraries.
* Sat Feb  4 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Trim filler words from description. RPM group fix.
* Wed Apr 25 2012 joop.boonen@opensuse.org
- Added a patch to fix gcc47 build errors
* Mon Apr 23 2012 joop.boonen@opensuse.org
- Build version 1.3.0
* Wed Dec  7 2011 Rene.vanPaassen@gmail.com
- added build dependency libtool, for openSUSE_Factory builds
- renamed Group to System/Libraries, to match packaging guidelines
* Sat Jul  2 2011 jengelh@medozas.de
- Remove conflicting %%debug_package: OBS deals with that already
- Remove unnecessary %%clean section
- Use %%_smp_mflags
* Sun Sep 21 2008 cmorve69@yahoo.es
- update to 1.2.0
